# Creating a Survey
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/creating-survey#introduction)
  * [Defining the Scope of a Survey](https://help.sap.com/docs/leanix/ea/creating-survey#defining-the-scope-of-a-survey)
  * [Designing a Survey](https://help.sap.com/docs/leanix/ea/creating-survey#designing-a-survey)
  * [Designing a Survey From Scratch](https://help.sap.com/docs/leanix/ea/creating-survey#designing-a-survey-from-scratch)
  * [Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/creating-survey#fact-sheet-fields)
  * [Basic Fields](https://help.sap.com/docs/leanix/ea/creating-survey#basic-fields)
  * [Advanced Fields](https://help.sap.com/docs/leanix/ea/creating-survey#advanced-fields)
  * [Adding Links and Descriptions](https://help.sap.com/docs/leanix/ea/creating-survey#adding-links-and-descriptions)


View all
Learn how to create surveys, from defining the scope and designing questions to using advanced fields and templates. Learn how to make questions mandatory, add links and descriptions, and import/export surveys.
